@@ -14,10 +14,10 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
   const char* class_name = "MyExe";
   
   // Class
-  int32_t method_id = env->get_class_method_id(env, class_name, "main", "int(string,string[])");
+  int32_t method_id = env->get_class_method_id(env, class_name, "main");
   
   if (method_id < 0) {
-    fprintf(stderr, "Can't find main method\n");
+    fprintf(stderr, "The class method %s->main is not defined\n", class_name);
     return -1;
   }
   
@@ -36,6 +36,7 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
     env->set_elem_object(env, stack, obj_argv, arg_index - 1, obj_arg);
   }
   
+  int32_t args_stack_length = 2;
   stack[0].oval = obj_program_name;
   stack[1].oval = obj_argv;
 
@@ -52,7 +53,7 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
   }
   
   // Run
-  int32_t error = env->call_spvm_method(env, stack, method_id);
+  int32_t error = env->call_spvm_method(env, stack, method_id, args_stack_length);
 
   int32_t status;
   if (error) {
